@@ -6,7 +6,7 @@ from ..brain_region import brain
 class BROADTENXCellAnnotation(CellAnnotation):
     __slots__ = ()
 
-    def __init__(self, annot_path, metadata):
+    def __init__(self, annot_path, metadata, add_l4_from_l3=True):
         super().__init__(annot_path)
 
         # add BROAD specific attributes
@@ -21,4 +21,10 @@ class BROADTENXCellAnnotation(CellAnnotation):
         metadata['SubRegion'] = metadata['DissectionRegion'].map(
             brain.map_dissection_region_to_sub_region())
         self['SubRegion'] = self['sample'].to_pandas().map(metadata['SubRegion'])
+
+        if add_l4_from_l3:
+            if 'L4' in self.data_vars:
+                raise ValueError('L4 already exists in annotation')
+            self['L4'] = self['L3'].copy()    
         return
+
