@@ -1,8 +1,11 @@
+from functools import lru_cache
+
+import numpy as np
 import pandas as pd
-from ..genome import mm10
+
 from wmb.files import *
 from ..annot import BROADTENXCellAnnotation
-from functools import lru_cache
+from ..genome import mm10
 
 
 class BROAD(AutoPathMixIn):
@@ -13,6 +16,8 @@ class BROAD(AutoPathMixIn):
         self.BROAD_TENX_CELL_TYPE_ANNOTATION_PATH = BROAD_TENX_CELL_TYPE_ANNOTATION_PATH
         self.BROAD_TENX_GENE_MAP_PATH = BROAD_TENX_GENE_MAP_PATH
 
+        self.BROAD_TENX_GENE_CHUNK_ZARR_PATH = BROAD_TENX_GENE_CHUNK_ZARR_PATH
+
         self._gene_zarr = None
         self._cell_million_reads = None
         self._gene_index = None
@@ -38,18 +43,18 @@ class BROAD(AutoPathMixIn):
         return BROADTENXCellAnnotation(self.BROAD_TENX_CELL_TYPE_ANNOTATION_PATH,
                                        self.get_tenx_sample_metadata())
 
-    def _open_zarr(self):
+    def _open_gene_chunk_zarr(self):
         import xarray as xr
-        self._gene_zarr = xr.open_zarr(self.BROAD_TENX_ZARR_PATH)
+        self._gene_zarr = xr.open_zarr(self.BROAD_TENX_GENE_CHUNK_ZARR_PATH)
         self._cell_million_reads = self._gene_zarr['umi_count'].to_pandas()
         self._cell_million_reads /= 1000000
         self._gene_index = self._gene_zarr.get_index('gene')
         return
 
     @lru_cache(maxsize=200)
-    def get_tenx_gene_data(self, gene, normalize=True):
+    def get_tenx_gene_data(self, gene, normalize=True, log=True):
         if self._gene_zarr is None:
-            self._open_zarr()
+            self._open_gene_chunk_zarr()
 
         # check if gene is gene name:
         if gene in self._gene_index:
@@ -59,13 +64,17 @@ class BROAD(AutoPathMixIn):
             gene_name = mm10.gene_id_to_name(gene)
 
         # raw counts
-        gene_data = self._gene_zarr['gene_da'].sel(
+        gene_data = self._gene_zarr['gene_da_fc'].sel(
             gene=gene_name).to_pandas()
+
         # normalize to CPM
         if normalize:
             gene_data /= self._cell_million_reads
+
+        # log transform
+        if log:
+            gene_data = np.log1p(gene_data)
         return gene_data
 
 
-
 broad = BROAD()
