@@ -45,9 +45,7 @@ CEMBA_SNM3C_3C_CHROM100K_RAW_ZARR_PATH = '/gale/netapp/cemba3c/BICCN/CEMBA_3C/mc
 # cluster assignments
 # cell class, major type, subtype
 CEMBA_SNMC_CELL_TYPE_ANNOTATION_PATH = '/gale/netapp/cemba3c/BICCN/wmb/cemba/CEMBA.snmC.Annotations.zarr'
-# TODO snm3C cell type annotation
-CEMBA_SNM3C_CELL_TYPE_ANNOTATION_PATH = None
-# CEMBA_SNM3C_CELL_TYPE_ANNOTATION_PATH = '/gale/netapp/cemba3c/BICCN/wmb/cemba/CEMBA.snm3C.Annotations.zarr'
+CEMBA_SNM3C_CELL_TYPE_ANNOTATION_PATH = '/gale/netapp/cemba3c/BICCN/wmb/cemba/CEMBA.snm3C.Annotations.zarr'
 
 # Outlier IDs
 # /home/hanliu/project/cemba/study/MarkOutlier 05/12/2022
@@ -57,6 +55,9 @@ CEMBA_SNM3C_OUTLIER_IDS_PATH = PACKAGE_DIR / 'files/CEMBA.snm3C.DoubletsID.txt.g
 # Liu 2021 Nature metadata
 CEMBA_LIU_2021_NATURE_SNMC_METADATA_PATH = PACKAGE_DIR / 'files/CEMBA.Liu2021Nature.snmC.metadata.csv.gz'
 
+# Gene chunk zarr path
+CEMBA_SNMC_GENE_CHUNK_ZARR_PATH = '/gale/netapp/cemba3c/BICCN/wmb/GeneChunks/CEMBA.snmC'
+CEMBA_SNM3C_GENE_CHUNK_ZARR_PATH = '/gale/netapp/cemba3c/BICCN/wmb/GeneChunks/CEMBA.snm3C'
 
 # =================================
 # CEMBA ATAC
@@ -66,3 +67,5 @@ CEMBA_ATAC_ZARR_PATH = '/gale/netapp/cemba3c/BICCN/CEMBA_ATAC/zarr/CEMBA.snATAC.
 CEMBA_ATAC_CELL_TYPE_ANNOTATION_PATH = '/gale/netapp/cemba3c/BICCN/CEMBA_ATAC/meta/CEMBA.snATAC.Annotations.zarr'
 CEMBA_ATAC_CLUSTER_FULL_NAME_PATH = PACKAGE_DIR / 'files/CEMBA.snATAC.ClusterDescription.tsv'
 CEMBA_ATAC_MAPPING_METRIC_PATH = '/gale/netapp/cemba3c/BICCN/CEMBA_ATAC/meta/CEMBA.snATAC.Metadata.hdf'
+
+CEMBA_ATAC_GENE_CHUNK_PATH = '/gale/netapp/cemba3c/BICCN/wmb/GeneChunks/CEMBA.ATAC'
\ No newline at end of file
